{% load cms_tags %}
<div class="row{% if instance.classes %} {{ instance.classes }}{% endif %}">
    {% for plugin in instance.child_plugin_instances %}
        {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
    {% endfor %}
</div>
