{% load cms_tags %}

<div class="panel-footer{% if instance.classes %} {{ instance.classes }}{% endif %}">
    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
</div>
