{% load cms_tags %}

<div class="accordion panel-group
    {% if instance.context %} panel-{{ instance.context }}{% endif %}
    {% if instance.classes %} {{ instance.classes }}{% endif %}"
    id="{{ accordion_id }}"
    role="tablist" aria-multiselectable="true">

    {% for plugin in instance.child_plugin_instances %}
        {% with parentloop=forloop index=instance.index %}
            {% render_plugin plugin %}
        {% endwith %}
    {% endfor %}
</div>
